config

package
v0.0.0-...-389ba5e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2020 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	ClientID            string
	ClientSecret        string
	Port                int
	DatabaseURL         string
	StateCookieName     string
	StateCookieExpiry   time.Duration
	SessionCookieName   string
	SessionCookieExpiry time.Duration
	OauthRedirectURL    string
	Environment         string
}

Config holds the settings used by the serve and build commands

func New

func New() (*Config, error)

New returns a Config struct with sane defaults and env variable overrides

Jump to